@@ -161,21 +161,12 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
             # CockroachDB doesn't support changing the primary key of table.
             'schema.tests.SchemaTests.test_alter_not_unique_field_to_primary_key',
             'schema.tests.SchemaTests.test_primary_key',
-            # ALTER COLUMN fails if previous asynchronous ALTER COLUMN hasn't
-            # finished. https://github.com/cockroachdb/cockroach/issues/47137
-            # These tests only fail sometimes, e.g.
-            # https://github.com/cockroachdb/cockroach/issues/65691
-            'schema.tests.SchemaTests.test_alter_field_db_collation',
-            'schema.tests.SchemaTests.test_alter_field_type_and_db_collation',
             # SmallAutoField doesn't work:
             # https://github.com/cockroachdb/cockroach-django/issues/84
             'bulk_create.tests.BulkCreateTests.test_bulk_insert_nullable_fields',
             'many_to_one.tests.ManyToOneTests.test_fk_to_smallautofield',
             'migrations.test_operations.OperationTests.test_smallfield_autofield_foreignfield_growth',
             'migrations.test_operations.OperationTests.test_smallfield_bigautofield_foreignfield_growth',
-            # This backend raises "ValueError: CockroachDB's EXPLAIN doesn't
-            # support any formats." instead of an "unknown format" error.
-            'queries.test_explain.ExplainTests.test_unknown_format',
             # unsupported comparison operator: <jsonb> > <string>:
             # https://github.com/cockroachdb/cockroach/issues/49144
             'model_fields.test_jsonfield.TestQuerying.test_deep_lookup_transform',
@@ -192,10 +183,6 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
             # unexpected partial unique index in pg_constraint query:
             # https://github.com/cockroachdb/cockroach/issues/61098
             'introspection.tests.IntrospectionTests.test_get_constraints_unique_indexes_orders',
-            # ALTER COLUMN ... SET NOT NULL crashes with "validate check
-            # constraint: column "crdb_internal_idx_expr" does not exist":
-            # https://github.com/cockroachdb/cockroach/issues/72012
-            'migrations.test_operations.OperationTests.test_alter_field_with_func_index',
         })
         if not self.connection.features.is_cockroachdb_21_1:
             expected_failures.update({
@@ -231,6 +218,13 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
     def django_test_skips(self):
         skips = super().django_test_skips
         skips.update({
+            # https://github.com/cockroachdb/cockroach/issues/47137
+            # These tests only fail sometimes, e.g.
+            # https://github.com/cockroachdb/cockroach/issues/65691
+            'ALTER COLUMN fails if previous asynchronous ALTER COLUMN has not finished.': {
+                'schema.tests.SchemaTests.test_alter_field_db_collation',
+                'schema.tests.SchemaTests.test_alter_field_type_and_db_collation',
+            },
             # https://github.com/cockroachdb/django-cockroachdb/issues/20
             'Unsupported query: UPDATE float column with integer column.': {
                 'expressions.tests.ExpressionsNumericTests',
