@@ -1,4 +1,3 @@
-from django.db.backends.base.introspection import TableInfo
 from django.db.backends.postgresql.introspection import (
     DatabaseIntrospection as PostgresDatabaseIntrospection,
 )
@@ -10,11 +9,6 @@ class DatabaseIntrospection(PostgresDatabaseIntrospection):
     data_types_reverse[1184] = 'DateTimeField'  # TIMESTAMPTZ
     index_default_access_method = 'prefix'
 
-    def get_table_list(self, cursor):
-        cursor.execute("SELECT table_name, type FROM [SHOW TABLES]")
-        # The second TableInfo field is 't' for table or 'v' for view.
-        return [TableInfo(row[0], 't' if row[1] == 'table' else 'v') for row in cursor.fetchall()]
-
     def get_constraints(self, cursor, table_name):
         """
         Retrieve any constraints or keys (unique, pk, fk, check, index) across
